==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRenderFunctionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRenderFunctionDescription } from "./WebRenderFunctionDescription";
/**
 * @hidden
 */
var WebRenderFunctionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRenderFunctionDescriptionMetadata, _super);
    function WebRenderFunctionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRenderFunctionDescriptionMetadata.b = function (a) {
        if (WebRenderFunctionDescriptionMetadata.a == null) {
            WebRenderFunctionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRenderFunctionDescriptionMetadata.c(WebRenderFunctionDescriptionMetadata.a);
        }
        if (a.j(WebRenderFunctionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRenderFunctionDescriptionMetadata.a);
    };
    WebRenderFunctionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RenderFunction");
    };
    WebRenderFunctionDescriptionMetadata.d = function (a) {
        WebRenderFunctionDescriptionMetadata.b(a);
        a.aa("WebRenderFunction", function () { return new WebRenderFunctionDescription(); });
        a.z("WebRenderFunction", WebRenderFunctionDescriptionMetadata.a);
    };
    WebRenderFunctionDescriptionMetadata.$t = markType(WebRenderFunctionDescriptionMetadata, 'WebRenderFunctionDescriptionMetadata');
    WebRenderFunctionDescriptionMetadata.a = null;
    return WebRenderFunctionDescriptionMetadata;
}(Base));
export { WebRenderFunctionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebRenderFunctionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRenderFunctionDescription } from "./WebRenderFunctionDescription";
/**
 * @hidden
 */
var WebRenderFunctionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRenderFunctionDescriptionMetadata, _super);
    function WebRenderFunctionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRenderFunctionDescriptionMetadata.b = function (a) {
        if (WebRenderFunctionDescriptionMetadata.a == null) {
            WebRenderFunctionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRenderFunctionDescriptionMetadata.c(WebRenderFunctionDescriptionMetadata.a);
        }
        if (a.k(WebRenderFunctionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRenderFunctionDescriptionMetadata.a);
    };
    WebRenderFunctionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RenderFunction");
    };
    WebRenderFunctionDescriptionMetadata.d = function (a) {
        WebRenderFunctionDescriptionMetadata.b(a);
        a.ac("WebRenderFunction", function () { return new WebRenderFunctionDescription(); });
        a.ab("WebRenderFunction", WebRenderFunctionDescriptionMetadata.a);
    };
    WebRenderFunctionDescriptionMetadata.$t = markType(WebRenderFunctionDescriptionMetadata, 'WebRenderFunctionDescriptionMetadata');
    WebRenderFunctionDescriptionMetadata.a = null;
    return WebRenderFunctionDescriptionMetadata;
}(Base));
export { WebRenderFunctionDescriptionMetadata };
